import simpleaudio as sa
import threading
import time
import os
import sys
import wave


class WavFile:
    def __init__(self, path):
        with wave.open(path, "rb") as f:
            self.width = f.getsampwidth()
            self.channels = f.getnchannels()
            self.rate = f.getframerate()
            self.frames = f.getnframes()
            self.data = f.readframes(self.frames)
            self.duration = float(self.frames) / self.rate


class WavPlayer:
    def __init__(self):

        self._sounds = dict()
        self._sounds_files = dict()
        self._threads = []

        if sys.platform.startswith("linux"):
            self.play = self.__play_linux
        elif sys.platform.startswith("win"):
            import winsound
            self.winsound = winsound
            self.play = self.__play_win
        else:
            self.play = self.__play_sa

    def add_sound(self, file, name):
        wave_obj = sa.WaveObject.from_wave_file(file)
        self._sounds[name] = wave_obj
        self._sounds_files[name] = file

    def stop(self):
        for th in self._threads:
            th.join()

    def __play_sa(self, sound_name):
        def _play():
            self._sounds[sound_name].play()
        thread = threading.Thread(target=_play, args=())
        self._threads.append(thread)
        thread.start()

    def __play_win(self, sound_name):
        self.winsound.PlaySound(self._sounds_files[sound_name], self.winsound.SND_ASYNC)

    def __play_linux(self, sound_name):
        os.system("aplay {}&".format(self._sounds_files[sound_name]))


if __name__ == "__main__":
    p = WavPlayer()
    p.add_sound(file="twenty.wav", name="one")
    p.play("one")
    time.sleep(1)
