from typing import Iterable, Dict
import json

from ..element import Element


def dump_elements(file_path: str, elements: Iterable[Element]) -> None:
    # Old variant
    # joblib.dump(elements, file_path, compress=9)

    # New variant
    d = {
        "elements": [element.to_json() for element in elements]
    }
    # This try save us in situation, when user pulled out a flash drive
    # At the same time with call of dump_elements
    try:
        with open(file_path, "w") as dump_file:
            json.dump(d, dump_file, separators=(",", ":"))  # Trim spaces
    except Exception:
        print("ERROR: can't save pins to {}".format(file_path))
        pass


def load_dict(file_path: str) -> Dict:

    with open(file_path, "r") as dump_file:
        d = json.load(dump_file)

    return d


def load_element(d) -> Element:

    if d is not None:
        element = list(map(Element.from_json, d["elements"]))[0]
    else:
        element = None

    return element
